/* 
 * MultiShapable.java 1.1 2002-06-13
 *
 *  2002 Jouni Smed
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *     * Neither the name of the University of Turku nor the names of its
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fi.utu.cs.appearance;

/**
 *  Provides definitions for objects comprising multiple shapable
 *  objects that can be displayed in the <code>Graphics2D</code> context. 
 *  The shapable objects given by the iterator are rendered first, and 
 *  the shapable object defined by the interface itself is rendered last.
 *  In other words, the methods are used followingly:
 *			<blockquote><code>
 *			MultiShapable ms;<br>
 *			</code>...<code><br>
 *			ShapeIterator si = ms.iterator();<br>
 *			while (si.hasNext())<br> 
 *			&nbsp;&nbsp;render(si.next());<br>
 *			render(ms);<br>
 *			</code></blockquote>
 *
 *  @see java.awt.Graphics2D
 *	@since 1.1
 *  @version 1.1, 020613
 *  @author  Jouni Smed
 */

public interface MultiShapable extends Shapable
  {
  public ShapeIterator iterator();
  }
