/* 
 * Constants.java 1.0 2002-08-21
 *
 *  2002 Jouni Smed
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *     * Neither the name of the University of Turku nor the names of its
 *       contributors may be used to endorse or promote products derived 
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fi.utu.cs.hockey.ai;

import fi.utu.cs.hockey.rink.Rink;
import fi.utu.cs.hockey.Player;
import fi.utu.cs.hockey.Puck;

/**
 *	Constants of the player, the puck, and the rink. All measures are given
 *	in meters. See an <a href="doc-files/Rink.pdf">illustration</a> of 
 *	the rink constants.
 *
 *  @version 1.0, 020821
 *  @author  Jouni Smed
 */

public interface Constants 
	{	
	/** Player's radius. */
	public double PLAYER_RADIUS = Player.RADIUS;

	/** Player's reachability. */
	public double PLAYER_REACHABILITY = Player.REACHABILITY;

	/** Diameter of the puck. */
	public double PUCK_DIAMETER = Puck.DIAMETER;

	/** Width of the rink. */
	public double RINK_WIDTH = Rink.WIDTH;

	/** Length of the rink. */
	public double RINK_LENGTH = Rink.LENGTH;

	/** Y-coordinate of own endboard. */
	public double OUR_ENDBOARD = -RINK_LENGTH / 2.0;
	
	/** Y-coordinate of opponent's endboard. */
	public double THEIR_ENDBOARD = RINK_LENGTH / 2.0;
	
	/** X-coordinate of the left endboard. */
	public double LEFT_ENDBOARD = -RINK_WIDTH / 2.0;

	/** X-coordinate of the right endboard. */
	public double RIGHT_ENDBOARD = -RINK_WIDTH / 2.0;

	/** Y-coordinate of own goal line. */
	public double OUR_GOAL_LINE = -Rink.GOAL_LINE_OFFSET;

	/** Y-coordinate of opponent's goal line. */
	public double THEIR_GOAL_LINE = Rink.GOAL_LINE_OFFSET;

	/** Y-coordinate of own blue line. */
	public double OUR_BLUE_LINE = -Rink.BLUE_LINE_OFFSET;

	/** Y-coordinate of opponent's blue line. */
	public double THEIR_BLUE_LINE = Rink.BLUE_LINE_OFFSET;

	/** Y-coordinate of the center line. */
	public double CENTER_LINE = 0.0;

	/** Y-coordinate of own endzone faceoff spot. */
	public double OUR_ENDZONE_FACEOFF = -Rink.ENDZONE_FACE_OFF_OFFSET;

	/** Y-coordinate of opponent's endzone faceoff spot. */
	public double THEIR_ENDZONE_FACEOFF = Rink.ENDZONE_FACE_OFF_OFFSET;

	/** Y-coordinate of own neutral zone faceoff spot. */
	public double OUR_NEUTRAL_ZONE_FACEOFF = -Rink.NEUTRAL_ZONE_FACE_OFF_OFFSET;

	/** Y-coordinate of opponent's neutral zone faceoff spot. */
	public double THEIR_NEUTRAL_ZONE_FACEOFF = Rink.NEUTRAL_ZONE_FACE_OFF_OFFSET;

	/** X-coordinate of a left side faceoff spot. */
	public double FACEOFF_LEFT = -Rink.FACE_OFF_OFFSET; 

	/** X-coordinate of a right side faceoff spot. */
	public double FACEOFF_RIGHT = Rink.FACE_OFF_OFFSET; 

	/** X-coordinate of the center faceoff spot. */
	public double FACEOFF_CENTER = 0.0;

	/** Radius of the center circle. */
	public double CENTER_CIRCLE_RADIUS =	Rink.CENTER_CIRCLE_RADIUS;	
		
	/** Radius of a faceoff circle. */
	public double FACEOFF_CIRCLE_RADIUS	= Rink.FACE_OFF_CIRCLE_RADIUS;	

	/** Width of the goal. */		
	public double GOAL_WIDTH = Rink.GOAL_WIDTH;

	/** Radius of the goal crease. */	
	public double GOAL_CREASE_RADIUS =	Rink.GOAL_CREASE_RADIUS;

	}

